@@ -4,6 +4,7 @@ using namespace CppUtilities;
 
 #include "../conversion/stringconversion.h"
 
+#ifndef CPP_UTILITIES_NO_ICONV
 /*!
  * \brief Allows printing std::wstring using CPPUNIT_ASSERT_EQUAL.
  */
@@ -19,6 +20,7 @@ std::ostream &operator<<(std::ostream &out, const std::wstring &s)
     out.write(utf8.first.get(), static_cast<std::streamsize>(utf8.second));
     return out;
 }
+#endif
 
 #include "../conversion/conversionexception.h"
 #include "../conversion/stringbuilder.h"
@@ -371,9 +373,14 @@ void IoTests::testPathUtilities()
     const auto expected = input;
     const auto output = makeNativePath(input);
 #ifdef PLATFORM_WINDOWS
+#ifndef CPP_UTILITIES_NO_ICONV
     const auto outputAsUtf8 = convertUtf16LEToUtf8(reinterpret_cast<const char *>(output.data()), output.size() * 2);
     const auto outputView = std::string_view(outputAsUtf8.first.get(), outputAsUtf8.second);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("makeNativePath()", expected, outputView);
+#else
+    CPP_UTILITIES_UNUSED(expected)
+    CPP_UTILITIES_UNUSED(output)
+#endif
 #else
     CPPUNIT_ASSERT_EQUAL_MESSAGE("makeNativePath()", expected, output);
 #endif
@@ -446,7 +453,7 @@ void IoTests::testAdvancedIniFile()
     CPPUNIT_ASSERT_EQUAL(7_st, options->fields.size());
     CPPUNIT_ASSERT_EQUAL("HoldPkg"s, options->fields[0].key);
     CPPUNIT_ASSERT_EQUAL("pacman glibc"s, options->fields[0].value);
-    CPPUNIT_ASSERT_MESSAGE("value present", options->fields[0].flags & IniFileFieldFlags::HasValue);
+    CPPUNIT_ASSERT_MESSAGE("value present", options->fields[0].flags && IniFileFieldFlags::HasValue);
 #ifdef STD_REGEX_WORKS
     TESTUTILS_ASSERT_LIKE_FLAGS("comment block between section header and first field",
         "# The following paths are.*\n.*#HookDir     = /etc/pacman\\.d/hooks/\n"s, std::regex::extended, options->fields[0].precedingCommentBlock);
@@ -454,7 +461,7 @@ void IoTests::testAdvancedIniFile()
     CPPUNIT_ASSERT_EQUAL(""s, options->fields[0].followingInlineComment);
     CPPUNIT_ASSERT_EQUAL("Foo"s, options->fields[1].key);
     CPPUNIT_ASSERT_EQUAL("bar"s, options->fields[1].value);
-    CPPUNIT_ASSERT_MESSAGE("value present", options->fields[1].flags & IniFileFieldFlags::HasValue);
+    CPPUNIT_ASSERT_MESSAGE("value present", options->fields[1].flags && IniFileFieldFlags::HasValue);
 #ifdef STD_REGEX_WORKS
     TESTUTILS_ASSERT_LIKE_FLAGS("comment block between fields", "#XferCommand.*\n.*#CleanMethod = KeepInstalled\n"s, std::regex::extended,
         options->fields[1].precedingCommentBlock);
@@ -462,7 +469,7 @@ void IoTests::testAdvancedIniFile()
     CPPUNIT_ASSERT_EQUAL("# inline comment"s, options->fields[1].followingInlineComment);
     CPPUNIT_ASSERT_EQUAL("CheckSpace"s, options->fields[3].key);
     CPPUNIT_ASSERT_EQUAL(""s, options->fields[3].value);
-    CPPUNIT_ASSERT_MESSAGE("no value present", !(options->fields[3].flags & IniFileFieldFlags::HasValue));
+    CPPUNIT_ASSERT_MESSAGE("no value present", !(options->fields[3].flags && IniFileFieldFlags::HasValue));
 #ifdef STD_REGEX_WORKS
     TESTUTILS_ASSERT_LIKE_FLAGS("empty lines in comments preserved", "\n# Pacman.*\n.*\n\n#NoUpgrade   =\n.*#TotalDownload\n"s, std::regex::extended,
         options->fields[3].precedingCommentBlock);
@@ -473,7 +480,7 @@ void IoTests::testAdvancedIniFile()
     CPPUNIT_ASSERT_EQUAL_MESSAGE("comment block which is only an empty line", "\n"s, extraScope->precedingCommentBlock);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("inline comment after scope", "# an inline comment after a scope name"s, extraScope->followingInlineComment);
     CPPUNIT_ASSERT_EQUAL(1_st, extraScope->fields.size());
-    CPPUNIT_ASSERT(ini.sections.back().flags & IniFileSectionFlags::Implicit);
+    CPPUNIT_ASSERT(ini.sections.back().flags && IniFileSectionFlags::Implicit);
 #ifdef STD_REGEX_WORKS
     TESTUTILS_ASSERT_LIKE_FLAGS("comment block after last field present in implicitly added last scope", "\n# If you.*\n.*custompkgs\n"s,
         std::regex::extended, ini.sections.back().precedingCommentBlock);
@@ -795,7 +802,10 @@ void IoTests::testExtractingArchive()
     CPPUNIT_ASSERT_EQUAL("test.txt"s, root.at(0).name);
     CPPUNIT_ASSERT_EQUAL(ArchiveFileType::Regular, root.at(0).type);
     CPPUNIT_ASSERT_EQUAL(DateTime::fromDate(1970, 1, 1), root.at(0).creationTime);
-    CPPUNIT_ASSERT_EQUAL(DateTime::fromDateAndTime(2024, 3, 3, 19, 46, 42), root.at(0).modificationTime);
+    // check only year and month of modification time as timezone is ambiguous, see remark in `archive.h` for details
+    // not guaranteed: CPPUNIT_ASSERT_EQUAL(DateTime::fromDateAndTime(2024, 3, 3, 20, 46, 42), DateTime::fromTimeStamp(root.at(0).modificationTime.toTimeStamp()));
+    CPPUNIT_ASSERT_EQUAL(2024, root.at(0).modificationTime.year());
+    CPPUNIT_ASSERT_EQUAL(3, root.at(0).modificationTime.month());
     CPPUNIT_ASSERT_EQUAL("testfile\n"s, root.at(0).content);
 
     CPPUNIT_ASSERT_EQUAL(1_st, subdir.size());
